<?php
/*
  $Id$

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2010 osCommerce

  Released under the GNU General Public License
*/

  ////////////////////////////////////////////////////////////////////////////////////////////////
  //
  // Function    : tep_validate_email
  //
  // Arguments   : email   email address to be checked
  //
  // Return      : true  - valid email address
  //               false - invalid email address
  //
  // Description : function for validating email address that conforms to RFC 822 specs
  //
  //              This function will first attempt to validate the Email address using the filter
  //              extension for performance. If this extension is not available it will
  //              fall back to a regex based validator which doesn't validate all RFC822
  //              addresses but catches 99.9% of them. The regex is based on the code found at
  //              http://www.regular-expressions.info/email.html
  //
  //              Optional validation for validating the domain name is also valid is supplied
  //              and can be enabled using the administration tool.
  //
  // Sample Valid Addresses:
  //
  //    first.last@host.com
  //    firstlast@host.to
  //    first-last@host.com
  //    first_last@host.com
  //
  // Invalid Addresses:
  //
  //    first last@host.com
  //    first@last@host.com
  //
  ////////////////////////////////////////////////////////////////////////////////////////////////
  function tep_validate_email($email) {
    $email = trim($email);

    if ( strlen($email) > 255 ) {
      $valid_address = false;
    } elseif ( function_exists('filter_var') && defined('FILTER_VALIDATE_EMAIL') ) {
     $valid_address = (bool)filter_var($email, FILTER_VALIDATE_EMAIL);
    } else {
      if ( substr_count( $email, '@' ) > 1 ) {
        $valid_address = false;
      }

      if ( preg_match("/[a-z0-9!#$%&'*+\/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&'*+\/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?/i", $email) ) {
        $valid_address = true;
      } else {
        $valid_address = false;
      }
    }

    if ($valid_address && ENTRY_EMAIL_ADDRESS_CHECK == 'true') {
      $domain = explode('@', $email);

      if ( !checkdnsrr($domain[1], "MX") && !checkdnsrr($domain[1], "A") ) {
        $valid_address = false;
      }
    }

    return $valid_address;
  }

/*
Derived from...

$Id: contact_us.php 7 2006-06-22 02:48:30Z user $
osCMax Power E-Commerce
http://oscdox.com
Copyright 2006 osCMax2005 osCMax, 2002 osCommerce
Released under the GNU General Public License

*
* Modified for use with osCommerce 2.3.1 by 'bitwit'
* Author: R. Paquette
* Date: 02/08/11
*/

// BEGIN - CAPTCHA Encryption Functionality
  function tep_CAP_RC4($data) {
    // change this key to something unique !!!!!!!!
    $key = 'top secret encryption phrase';                      
    // To Encrypt - Call CAP_RC4 with plain text.
    // To Decrypt - Call CAP_RC4 with encrypted text.
    $key_length = strlen($key);   
    for ($i = 0; $i < 255; $i++) {
      $key[$i] = ord(substr($key, ($i % $key_length)+1, 1));
      $counter[$i] = $i;
    }
    for ($i = 0; $i < 255; $i++) {
      $x = ($x + $counter[$i] + $key[$i]) % 256;
      $temp_swap = $counter[$i];  
      $counter[$i] = $counter[$x];
      $counter[$x] = $temp_swap;
    }
    for ($i = 0; $i < strlen($data); $i++) {
      $a = ($a + 1) % 256;
      $j = ($j + $counter[$a]) % 256;
      $temp = $counter[$a];
      $counter[$a] = $counter[$j];
      $counter[$j] = $temp;
      $k = $counter[(($counter[$a] + $counter[$j]) % 256)];
      $Xcipher = ord(substr($data, $i, 1)) ^ $k;
      $Xcrypt .= chr($Xcipher);
    }
    return $Xcrypt;
  }

  function tep_urlsafe_b64encode($string) {
    $data = base64_encode($string);
    $data = str_replace(array('+','/','='),array('-','_',''),$data);
    return $data;
  }

  function tep_urlsafe_b64decode($string) {
    $data = str_replace(array('-','_'),array('+','/'),$string);
    $mod4 = strlen($data) % 4;
    if ($mod4) {
      $data .= substr('====', $mod4);
    }
    return base64_decode($data);
  }

// END - CAPTCHA Encryption Functionality

/*
* CaptchaSecurityImages.php
* Author: Simon Jarvis
* Copyright: 2006 Simon Jarvis
* Date: 03/08/06
* Updated: 07/02/07
* Requirements: PHP 4/5 with GD and FreeType libraries
* Link: http://www.white-hat-web-design.co.uk/articles/php-captcha.php
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details:
* http://www.gnu.org/licenses/gpl.html
*
*/

/*
* Modified for use with osCommerce 2.3.1 by 'bitwit'
* Author: R. Paquette
* Date: 02/06/11
*/
	function tep_captcha_code($characters) {
		// list all possible characters, similar looking characters and vowels have been removed
		// when using other than basic mono font make sure letters are recognizable
		$possible = '23456789bcdghkmnpqrsvwxz';
		$code = '';
		$i = 0;
		while ($i < $characters) {
			$code .= substr($possible, mt_rand(0, strlen($possible)-1), 1);
			$i++;
		}
		return $code;
	}

        function tep_captcha_image($width='150',$height='50',$characters='6') {
		$code = tep_captcha_code($characters);
		/* font size will be 65% of the image height */
		$font_size = $height * 0.65;
		$image = @imagecreate($width, $height) or die('Cannot initialize new GD image stream');
		/* set the colours */
		$background_color = imagecolorallocate($image, 255, 255, 255);
		$text_color = imagecolorallocate($image, 60, 80, 100);
		$noise_color = imagecolorallocate($image, 100, 120, 180);
		/* generate random dots in background */
		for( $i=0; $i<($width*$height)/3; $i++ ) {
			imagefilledellipse($image, mt_rand(0,$width), mt_rand(0,$height), 1, 1, $noise_color);
		}
		/* generate random lines in background */
		for( $i=0; $i<($width*$height)/150; $i++ ) {
			imageline($image, mt_rand(0,$width), mt_rand(0,$height), mt_rand(0,$width), mt_rand(0,$height), $noise_color);
		}
		/* create textbox and add text */
		$textbox = imagettfbbox($font_size, 0, CAPTCHA_FONT , $code) or die('Error in imagettfbbox function');
		$x = ($width - $textbox[4])*0.5;
		$y = ($height - $textbox[5])*0.45; // just a little higher than middle for decenders
		imagettftext($image, $font_size, 0, $x, $y, $text_color, CAPTCHA_FONT , $code) or die('Error in imagettftext function');
                /* output captcha image to file */
                imagejpeg($image, CAPTCHA_IMAGE);
                imagedestroy($image);
                /* return the encoded encrypted code for this image */
                return tep_urlsafe_b64encode(tep_CAP_RC4($code));
	}

?>